@@ -2,8 +2,9 @@
 
 """
 Created on Mon May  7 14:08:56 2018
+Last modified October 30 18:41:00 2019
 
-@author: a.teffal
+@author: Amine TEFFAL
 
 """
 
@@ -180,9 +181,7 @@ def get_cols_values(employees_proj_, id_e, spouses_proj_,
 
     
 
-def projectNumbers(employees, spouses, children, mortalityTable = 'TV 88-90', MAX_YEARS = 50, law_retirement_ = None, 
-                    law_resignation_ = None, law_marriage_ = None, age_diff = 5, marriage_periode = ['active', 'retired'],
-                    law_birth_ = None, birth_periode = ['active', 'retired'], law_replacement_ =  None):
+def projectNumbers(employees, spouses, children, mortalityTable = 'TV 88-90', MAX_YEARS = 50, law_retirement_ = None,  law_resignation_ = None, law_marriage_ = None, age_diff = 5, marriage_periode = ['active', 'retired'], law_birth_ = None, birth_periode = ['active', 'retired'], max_child_age = 120, law_replacement_ =  None):
     
     """ Main function that project population of a retirement plan (employees their spouses and their children) given laws of :
         mortality, retirement, resignation, marriage, birth and replacement.
@@ -247,9 +246,25 @@ def projectNumbers(employees, spouses, children, mortalityTable = 'TV 88-90', MA
         - n_new_retirees a list storing number of retirees for each year 
     """
 
-    # if group doesn't exist in employees create it and set it to be id
+    # if column group doesn't exist in employees create it and set it to be 1 for active and 0 for retired
     if not 'group' in list(employees):
-        employees['group'] = employees['id']
+        employees['group']=1
+        employees.loc[employees['type']=='active',['group']] = 1
+        employees.loc[employees['type']=='retired',['group']] = 0
+
+    # if column number doesn't exist in employees create it and set it to for all
+    if not 'number' in list(employees):
+        employees['number'] = 1
+
+    # if column number doesn't exist in spouses create it and set it to for all
+    if not 'number' in list(spouses):
+        spouses['number'] = 1
+
+    # if column number doesn't exist in children create it and set it to for all
+    if not 'number' in list(children):
+        children['number'] = 1
+    
+    
 
     #setting law of retirement
     if law_retirement_ == None:
@@ -623,9 +638,14 @@ def projectNumbers(employees, spouses, children, mortalityTable = 'TV 88-90', MA
             # if new child continue (treate next year)
             if child['entrance'] > i:
                 continue
+
             
             #update age of children
             age = child["data"]['age']
+
+            # if age of child equals max_child_age, continue
+            if age >= max_child_age:
+                continue
             
             #probability of surviving
             survie = act.sfs_nPx(age,1, mortalityTable)
@@ -963,7 +983,7 @@ def individual_spouses_numbers(spouses_proj_):
     return df_lives, df_deaths, df_types, df_rev, df_res
 
 
-def individual_children_numbers(children_proj_, max_child_age = 120): 
+def individual_children_numbers(children_proj_): 
     """
     Returns a tuple of four data frames : projected lives, deaths and 
     type for children
